# Generated by Django 4.2.27 on 2026-02-02 21:57

from django.db import migrations, models


class Migration(migrations.Migration):

    initial = True

    dependencies = []

    operations = [
        migrations.CreateModel(
            name="Sequence",
            fields=[
                (
                    "id",
                    models.BigAutoField(
                        auto_created=True,
                        primary_key=True,
                        serialize=False,
                        verbose_name="ID",
                    ),
                ),
                (
                    "key",
                    models.CharField(
                        help_text="Unique identifier for this sequence in format: app_label.model_name.field_name",
                        max_length=255,
                        unique=True,
                    ),
                ),
                (
                    "last_value",
                    models.PositiveIntegerField(
                        default=0,
                        help_text="The last number handed out by this sequence",
                    ),
                ),
                (
                    "created_at",
                    models.DateTimeField(
                        auto_now_add=True,
                        help_text="When this sequence was first created",
                    ),
                ),
                (
                    "updated_at",
                    models.DateTimeField(
                        auto_now=True,
                        help_text="When this sequence was last incremented",
                    ),
                ),
            ],
            options={
                "verbose_name": "Formatted AutoField Sequence",
                "verbose_name_plural": "Formatted AutoField Sequences",
                "db_table": "formatted_autofield_sequence",
                "indexes": [models.Index(fields=["key"], name="idx_sequence_key")],
            },
        ),
    ]
