from django.apps import AppConfig


class FormattedAutoFieldConfig(AppConfig):
    """
    Configuration for the formatted_autofield Django app.
    """

    default_auto_field = 'django.db.models.BigAutoField'
    name = 'formatted_autofield'
    verbose_name = 'Formatted AutoField'

    def ready(self):
        """
        Called when Django starts.

        This method is called once Django has finished setting up.
        Use it to import signal handlers, perform system checks, etc.
        """
        # Nothing to do here yet, but keeping the method for future use
        pass
